diff --git a/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.xml b/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.xml
index 734d945514e64bb0f7f0bd93657b5476c3bf46cf..0e32c67d0ff55ab03f6830ff9a89d0a99ef000ee 100644
--- a/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.xml
+++ b/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.xml
@@ -273,7 +273,7 @@
             </item>
             <item>
                 <key> <string>serial</string> </key>
-                <value> <string>964.45561.47559.9591</string> </value>
+                <value> <string>965.1757.48193.16793</string> </value>
             </item>
             <item>
                 <key> <string>state</string> </key>
@@ -291,7 +291,7 @@
                     </tuple>
                     <state>
                       <tuple>
-                        <float>1515684256.04</float>
+                        <float>1516800617.44</float>
                         <string>UTC</string>
                       </tuple>
                     </state>
diff --git a/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.js b/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.js
index 269f2e33f5110edf629e9f2b536db7d63998c3f0..88b22d8f4f09983d796a1832076e1823f4e38f40 100644
--- a/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.js
+++ b/bt5/erp5_officejs/PathTemplateItem/web_page_module/gadget_officejs_page_jio_erp5_configurator_js.js
@@ -1,7 +1,6 @@
-/*global window, rJS, RSVP, URI, location,
-    loopEventListener, btoa */
+/*global window, rJS, RSVP, URI, navigator */
 /*jslint nomen: true, indent: 2, maxerr: 3*/
-(function (window, rJS, RSVP) {
+(function (window, rJS, RSVP, URI, navigator) {
   "use strict";
 
   function setjIOERP5Configuration(gadget) {
@@ -18,8 +17,12 @@
         var configuration = {},
           portal_type = result[0],
           attachment_synchro = result[1] !== "",
-          extended_attachment_url = result[1];
-
+          extended_attachment_url = result[1],
+          // https://bugs.chromium.org/p/chromium/issues/detail?id=375297
+          // mobile device memory is limited for blob,
+          // we reach this limit with parallel operation.
+          is_low_memory = (navigator.userAgent.indexOf("Chrome") > 0) &&
+            (navigator.userAgent.indexOf('Mobile') > 0);
         configuration = {
           type: "replicate",
           // XXX This drop the signature lists...
@@ -30,8 +33,8 @@
           },
           use_remote_post: true,
           conflict_handling: 1,
-          parallel_operation_attachment_amount: 10,
-          parallel_operation_amount: 10,
+          parallel_operation_attachment_amount: is_low_memory ? 1 : 10,
+          parallel_operation_amount: is_low_memory ? 1 : 10,
 //          signature_hash_key: "modification_date",
           check_local_attachment_modification: attachment_synchro,
           check_local_attachment_creation: attachment_synchro,
@@ -233,4 +236,4 @@
         });
     });
 
-}(window, rJS, RSVP));
+}(window, rJS, RSVP, URI, navigator));